==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/panel/translations/razor-panel_sk_SK.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <source>Configure panel</source>
        <translation>Nastaviť panel</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Výška:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Šírka:</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vľavo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <source>Center</source>
        <translation>Stred</translation>
    </message>
    <message>
        <source>Alignment</source>
        <translation>Zarovnanie</translation>
    </message>
</context>
<context>
    <name>PositionAction</name>
    <message>
        <source>Top of desktop</source>
        <translation>Vrch plochy</translation>
    </message>
    <message>
        <source>Bottom of desktop</source>
        <translation>Spodok plochy</translation>
    </message>
    <message>
        <source>Left of desktop</source>
        <translation>Ľavá strana plochy</translation>
    </message>
    <message>
        <source>Right of desktop</source>
        <translation>Pravá strana plochy</translation>
    </message>
    <message>
        <source>Top of desktop %1</source>
        <translation>Vrch plochy %1</translation>
    </message>
    <message>
        <source>Bottom of desktop %1</source>
        <translation>Spodok plochy %1</translation>
    </message>
    <message>
        <source>Left of desktop %1</source>
        <translation>Ľavá strana plochy %1</translation>
    </message>
    <message>
        <source>Right of desktop %1</source>
        <translation>Pravá strana plochy %1</translation>
    </message>
</context>
<context>
    <name>RazorPanelPrivate</name>
    <message>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Zásuvné moduly</translation>
    </message>
    <message>
        <source>Add plugins ...</source>
        <translation>Pridať moduly...</translation>
    </message>
    <message>
        <source>Move plugin</source>
        <translation>Presunúť modul</translation>
    </message>
    <message>
        <source>Configure plugin</source>
        <translation>Nastaviť modul</translation>
    </message>
    <message>
        <source>Delete plugin</source>
        <translation>Zmazať modul</translation>
    </message>
    <message>
        <source>Show this panel at</source>
        <translation>Zobraziť tento panel na</translation>
    </message>
    <message>
        <source>Configure panel</source>
        <translation>Nastaviť panel</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/panel/translations/razor-panel_sk_SK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk_SK" version="2.0">
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <source>Configure panel</source>
        <translation>Nastaviť panel</translation>
    </message>
    <message>
        <source>Panel size</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Size:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <source>Use automatic sizing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Panel length &amp;&amp; position</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Left</source>
        <translation>Vľavo</translation>
    </message>
    <message>
        <source>Center</source>
        <translation>Stred</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Alignment:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Length:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Position:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Top of desktop</source>
        <translation>Vrch plochy</translation>
    </message>
    <message>
        <source>Left of desktop</source>
        <translation>Ľavá strana plochy</translation>
    </message>
    <message>
        <source>Right of desktop</source>
        <translation>Pravá strana plochy</translation>
    </message>
    <message>
        <source>Bottom of desktop</source>
        <translation>Spodok plochy</translation>
    </message>
    <message>
        <source>Top of desktop %1</source>
        <translation>Vrch plochy %1</translation>
    </message>
    <message>
        <source>Left of desktop %1</source>
        <translation>Ľavá strana plochy %1</translation>
    </message>
    <message>
        <source>Right of desktop %1</source>
        <translation>Pravá strana plochy %1</translation>
    </message>
    <message>
        <source>Bottom of desktop %1</source>
        <translation>Spodok plochy %1</translation>
    </message>
</context>
<context>
    <name>RazorPanel</name>
    <message>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <source>Configure panel...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add plugins ...</source>
        <translation>Pridať moduly...</translation>
    </message>
</context>
<context>
    <name>RazorPanelPlugin</name>
    <message>
        <source>Configure</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Move</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RazorPanelPrivate</name>
    <message>
        <source>Configure panel</source>
        <translation>Nastaviť panel</translation>
    </message>
</context>
</TS>
